@@ -23,8 +23,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     GetAppMonitorDataResponseTypeDef,
@@ -47,7 +46,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class GetAppMonitorDataPaginator(Boto3Paginator):
+class GetAppMonitorDataPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Paginator.GetAppMonitorData)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/paginators/#getappmonitordatapaginator)
@@ -67,7 +66,7 @@ class GetAppMonitorDataPaginator(Boto3Paginator):
         """
 
 
-class ListAppMonitorsPaginator(Boto3Paginator):
+class ListAppMonitorsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Paginator.ListAppMonitors)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/paginators/#listappmonitorspaginator)
